==> ros-melodic-rviz_1.13.12.orig.tar.gz: ros-melodic-rviz-1.13.12/README.md <==
![rviz logo](https://raw.githubusercontent.com/ros-visualization/rviz/melodic-devel/images/splash.png)

[![Build Status](http://build.ros.org/buildStatus/icon?job=Mdev__rviz__ubuntu_bionic_amd64)](http://build.ros.org/view/Mdev/job/Mdev__rviz__ubuntu_bionic_amd64/)

rviz is a 3D visualizer for the Robot Operating System (ROS) framework.

For more information, please see the wiki: http://wiki.ros.org/rviz

This package contains Public Domain icons downloaded from http://tango.freedesktop.org/releases/.

Upstream Authors (2005-2009):

- Ulisse Perusin `<uli.peru@gmail.com>`
- Steven Garrity `<sgarrity@silverorange.com>`
- Lapo Calamandrei `<calamandrei@gmail.com>`
- Ryan Collier `<rcollier@novell.com>`
- Rodney Dawes `<dobey@novell.com>`
- Andreas Nilsson `<nisses.mail@home.se>`
- Tuomas Kuosmanen `<tigert@tigert.com>`
- Garrett LeSage `<garrett@novell.com>`
- Jakub Steiner `<jimmac@novell.com>`

Other icons and graphics contained in this package are released into the
Public Domain as well.

Authors (2012-2019):

- David Gossow
- Chad Rockey
- Kei Okada
- Julius Kammerl
- Acorn Pooley
- Rein Appeldoorn
- Robert Haschke

Copyright notice for all icons and graphics in this package:

```
Public Domain Dedication

Copyright-Only Dedication (based on United States law) or Public Domain
Certification

The person or persons who have associated work with this document (the
"Dedicator" or "Certifier") hereby either (a) certifies that, to the best
of his knowledge, the work of authorship identified is in the public
domain of the country from which the work is published, or (b)
hereby dedicates whatever copyright the dedicators holds in the work
of authorship identified below (the "Work") to the public domain. A
certifier, moreover, dedicates any copyright interest he may have in
the associated work, and for these purposes, is described as a
"dedicator" below.

A certifier has taken reasonable steps to verify the copyright
status of this work. Certifier recognizes that his good faith efforts
may not shield him from liability if in fact the work certified is not
in the public domain.

Dedicator makes this dedication for the benefit of the public at
large and to the detriment of the Dedicator's heirs and successors.
Dedicator intends this dedication to be an overt act of relinquishment
in perpetuity of all present and future rights under copyright law,
whether vested or contingent, in the Work. Dedicator understands that
such relinquishment of all rights includes the relinquishment of all
rights to enforce (by lawsuit or otherwise) those copyrights in the
Work.

Dedicator recognizes that, once placed in the public domain, the Work
may be freely reproduced, distributed, transmitted, used, modified,
built upon, or otherwise exploited by anyone for any purpose, commercial
or non-commercial, and in any way, including by methods that have not
yet been invented or conceived.
```

Source: http://creativecommons.org/licenses/publicdomain/

==> ros-melodic-rviz_1.13.30.orig.tar.gz: ros-melodic-rviz-1.13.30/README.md <==
![rviz logo](https://raw.githubusercontent.com/ros-visualization/rviz/melodic-devel/images/splash.png)

[![Build Status](http://build.ros.org/buildStatus/icon?job=Mdev__rviz__ubuntu_bionic_amd64)](http://build.ros.org/view/Mdev/job/Mdev__rviz__ubuntu_bionic_amd64/)

rviz is a 3D visualizer for the Robot Operating System (ROS) framework.

For more information, please see the wiki: http://wiki.ros.org/rviz

Maintainers:
- Robert Haschke (2019-)
- William Woodall (2013-2018)
- David Gossow (2013)
- Dave Hershberger (2011-2013)
- Josh Faust (2010)

This package contains Public Domain icons downloaded from http://tango.freedesktop.org/releases/.

Other icons and graphics contained in this package are released into the Public Domain as well.

Copyright notice for all icons and graphics in this package:

```
Public Domain Dedication

Copyright-Only Dedication (based on United States law) or Public Domain
Certification

The person or persons who have associated work with this document (the
"Dedicator" or "Certifier") hereby either (a) certifies that, to the best
of his knowledge, the work of authorship identified is in the public
domain of the country from which the work is published, or (b)
hereby dedicates whatever copyright the dedicators holds in the work
of authorship identified below (the "Work") to the public domain. A
certifier, moreover, dedicates any copyright interest he may have in
the associated work, and for these purposes, is described as a
"dedicator" below.

A certifier has taken reasonable steps to verify the copyright
status of this work. Certifier recognizes that his good faith efforts
may not shield him from liability if in fact the work certified is not
in the public domain.

Dedicator makes this dedication for the benefit of the public at
large and to the detriment of the Dedicator's heirs and successors.
Dedicator intends this dedication to be an overt act of relinquishment
in perpetuity of all present and future rights under copyright law,
whether vested or contingent, in the Work. Dedicator understands that
such relinquishment of all rights includes the relinquishment of all
rights to enforce (by lawsuit or otherwise) those copyrights in the
Work.

Dedicator recognizes that, once placed in the public domain, the Work
may be freely reproduced, distributed, transmitted, used, modified,
built upon, or otherwise exploited by anyone for any purpose, commercial
or non-commercial, and in any way, including by methods that have not
yet been invented or conceived.
```

Source: http://creativecommons.org/licenses/publicdomain/
